# -*- coding: utf-8 -*-
"""
DO NOT EDIT! This file is auto-generated

Classes for Skyline Message Bus usage.
"""
from __future__ import absolute_import

# Import python libs
import json
import sys
from datetime import datetime  # pylint: disable=unused-import

# Import local libs
# pylint: disable=import-error
from niskyline.messagebus.broadcast_message import BroadcastMessage  # pylint: disable=unused-import
from niskyline.messagebus.datetime import from_datetime, to_datetime  # pylint: disable=unused-import
from niskyline.messagebus.message_header import (  # pylint: disable=unused-import
    MessageHeader, JSON_MESSAGE_CONTENT_TYPE, BINARY_MESSAGE_CONTENT_TYPE)
from niskyline.messagebus.message_base import MessageBase
from niskyline.messagebus.request_message import RequestMessage  # pylint: disable=unused-import
from niskyline.messagebus.response_message import ResponseMessage  # pylint: disable=unused-import
from niskyline.messagebus.routed_message import RoutedMessage  # pylint: disable=unused-import
# pylint: enable=import-error

if sys.version_info[0] >= 3:
    long = int  # pylint: disable=redefined-builtin,invalid-name


# pylint: disable=line-too-long,too-many-lines,too-many-instance-attributes


#
# Configuration service
#


class SectionKeyValues(object):
    """
    SectionKeyValues custom data type.
    """
    def __init__(self,
                 section_,
                 key_values_):
        """
        :param section_: section
        :type section_: str
        :param key_values_: key_values
        :type key_values_: dict(str, str)
        """
        self.section = section_
        self.key_values = key_values_

    @classmethod
    def from_dict(cls, body_dict):
        """
        Create a new instance of :class:`SectionKeyValues` using a dictionary.

        :param body_dict: A dictionary representing the body.
        :type body_dict: dict
        :return: A new instance of :class:`SectionKeyValues`.
        :rtype: SectionKeyValues
        """
        section_ = body_dict.get('section')
        key_values_ = body_dict.get('keyValues')
        return cls(
            section_=section_,
            key_values_=key_values_
        )

    @classmethod
    def from_json(cls, body_json):
        """
        Create a new instance of :class:`SectionKeyValues` using a JSON string.

        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`SectionKeyValues`.
        :rtype: SectionKeyValues
        """
        body_dict = json.loads(body_json)
        return cls.from_dict(body_dict)

    @classmethod
    def from_body_bytes(cls, body_bytes):
        """
        Create a new instance of :class:`SectionKeyValues` using a body
        of type :class:`bytes` or :class:`bytesarray`.

        :param body_bytes: The body to use.
        :type body_bytes: bytes or bytesarray
        :return: A new instance of :class:`SectionKeyValues`.
        :rtype: SectionKeyValues
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(body_json)

    def to_dict(self):
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: dict
        """
        section_ = self.section
        key_values_ = self.key_values
        return {
            'section': section_,
            'keyValues': key_values_
        }

    def to_json(self):
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        body_json = self.to_json()
        return bytearray(body_json, 'utf-8')


class ConfigurationGetKeysRequest(RequestMessage):
    """
    ConfigurationGetKeysRequest JSON request message.
    """
    def __init__(self,
                 section_):
        """
        :param section_: section
        :type section_: str
        """
        self.section = section_
        header = MessageHeader()
        header.set_message_name('ConfigurationGetKeysRequest')
        header.set_content_type(JSON_MESSAGE_CONTENT_TYPE)
        routing_key = MessageHeader.generate_routing_key('Configuration', 'ConfigurationGetKeysRequest')
        header.set_routing_key(routing_key)
        super(ConfigurationGetKeysRequest, self).__init__(header, None)

    @classmethod
    def from_dict(cls, body_dict):
        """
        Create a new instance of :class:`ConfigurationGetKeysRequest` using a dictionary.

        :param body_dict: The body as a dictionary.
        :type body_dict: dict
        :return: A new instance of :class:`ConfigurationGetKeysRequest`.
        :rtype: ConfigurationGetKeysRequest
        """
        section_ = body_dict.get('section')
        return cls(
            section_=section_
        )

    @classmethod
    def from_json(cls, body_json):
        """
        Create a new instance of :class:`ConfigurationGetKeysRequest` using a JSON string.

        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`ConfigurationGetKeysRequest`.
        :rtype: ConfigurationGetKeysRequest
        """
        body_dict = json.loads(body_json)
        return cls.from_dict(body_dict)

    @classmethod
    def from_body_bytes(cls, body_bytes):
        """
        Create a new instance of :class:`ConfigurationGetKeysRequest` using a body
        of type :class:`bytes` or :class:`bytesarray`,

        :param body_bytes: The body to use.
        :type body_bytes: bytes or bytesarray
        :return: A new instance of :class:`ConfigurationGetKeysRequest`.
        :rtype: ConfigurationGetKeysRequest
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(body_json)

    @classmethod
    def from_message(cls, message):
        """
        Create a new instance of :class`ConfigurationGetKeysRequest` using a
        :class:`niskyline.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: niskyline.messagebus.message_base.MessageBase
        :return: A new instance of :class`ConfigurationGetKeysRequest`.
        :rtype: ConfigurationGetKeysRequest
        """
        instance = cls.from_body_bytes(message.get_body_bytes())
        instance.set_correlation_id(message.get_correlation_id())
        instance.set_reply_to(message.get_reply_to())
        return instance

    def to_dict(self):
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: dict
        """
        section_ = self.section
        return {
            'section': section_
        }

    def to_json(self):
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        body_json = self.to_json()
        return bytearray(body_json, 'utf-8')

    def to_message(self, request_message=None):
        """
        Returns a :class:`niskyline.messagebus.message_base.MessageBase`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :return: A :class:`niskyline.messagebus.message_base.MessageBase`
            object representing the data in this object.
        :rtype: niskyline.messagebus.message_base.MessageBase
        """
        header = self.get_header()
        if request_message:
            request_header = request_message.get_header()
            header.set_correlation_id(request_header.get_correlation_id())
        body_bytes = self.to_body_bytes()
        return MessageBase(header, body_bytes)

    def get_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body


class ConfigurationGetKeysResponse(ResponseMessage):
    """
    ConfigurationGetKeysResponse JSON response message.
    """
    def __init__(self,
                 request_message,
                 keys_):
        """
        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param keys_: keys
        :type keys_: dict(str, str)
        """
        self.keys = keys_
        header = MessageHeader()
        header.set_message_name('ConfigurationGetKeysResponse')
        header.set_content_type(JSON_MESSAGE_CONTENT_TYPE)
        # If request_message is None, routing key needs to be set outside this constructor.
        if request_message:
            header.set_correlation_id(request_message.get_correlation_id())
            routing_key = MessageHeader.generate_routing_key(request_message.get_reply_to(), 'ConfigurationGetKeysResponse')
            header.set_routing_key(routing_key)
        super(ConfigurationGetKeysResponse, self).__init__(header, None)

    @classmethod
    def from_dict(cls, request_message, body_dict):
        """
        Create a new instance of :class:`ConfigurationGetKeysResponse` using a dictionary.

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param body_dict: The body as a dictionary.
        :type body_dict: dict
        :return: A new instance of :class:`ConfigurationGetKeysResponse`.
        :rtype: ConfigurationGetKeysResponse
        """
        keys_ = body_dict.get('keys')
        return cls(
            request_message,
            keys_=keys_
        )

    @classmethod
    def from_json(cls, request_message, body_json):
        """
        Create a new instance of :class:`ConfigurationGetKeysResponse` using a JSON string.

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`ConfigurationGetKeysResponse`.
        :rtype: ConfigurationGetKeysResponse
        """
        body_dict = json.loads(body_json)
        return cls.from_dict(request_message, body_dict)

    @classmethod
    def from_body_bytes(cls, request_message, body_bytes):
        """
        Create a new instance of :class:`ConfigurationGetKeysResponse` using a body
        of type :class:`bytes` or :class:`bytesarray`,

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param body_bytes: The body to use.
        :type body_bytes: bytes or bytesarray
        :return: A new instance of :class:`ConfigurationGetKeysResponse`.
        :rtype: ConfigurationGetKeysResponse
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(request_message, body_json)

    @classmethod
    def from_message(cls, message):
        """
        Create a new instance of :class`ConfigurationGetKeysResponse` using a
        :class:`niskyline.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: niskyline.messagebus.message_base.MessageBase
        :return: A new instance of :class`ConfigurationGetKeysResponse`.
        :rtype: ConfigurationGetKeysResponse
        """
        instance = cls.from_body_bytes(message, message.get_body_bytes())
        instance.set_correlation_id(message.get_correlation_id())
        instance.set_reply_to(message.get_reply_to())
        routing_key = MessageHeader.generate_routing_key(message.get_reply_to(), 'ConfigurationGetKeysResponse')
        instance.set_routing_key(routing_key)
        return instance

    def to_dict(self):
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: dict
        """
        keys_ = self.keys
        return {
            'keys': keys_
        }

    def to_json(self):
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        body_json = self.to_json()
        return bytearray(body_json, 'utf-8')

    def to_message(self, request_message=None):
        """
        Returns a :class:`niskyline.messagebus.message_base.MessageBase`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :return: A :class:`niskyline.messagebus.message_base.MessageBase`
            object representing the data in this object.
        :rtype: niskyline.messagebus.message_base.MessageBase
        """
        header = self.get_header()
        if request_message:
            request_header = request_message.get_header()
            header.set_correlation_id(request_header.get_correlation_id())
            routing_key = MessageHeader.generate_routing_key(request_header.get_reply_to(), 'ConfigurationGetKeysResponse')
            header.set_routing_key(routing_key)
        body_bytes = self.to_body_bytes()
        return MessageBase(header, body_bytes)

    def get_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body


class ConfigurationSetKeysRequest(RequestMessage):
    """
    ConfigurationSetKeysRequest JSON request message.
    """
    def __init__(self,
                 user_,
                 section_,
                 keys_):
        """
        :param user_: user
        :type user_: str
        :param section_: section
        :type section_: str
        :param keys_: keys
        :type keys_: dict(str, str)
        """
        self.user = user_
        self.section = section_
        self.keys = keys_
        header = MessageHeader()
        header.set_message_name('ConfigurationSetKeysRequest')
        header.set_content_type(JSON_MESSAGE_CONTENT_TYPE)
        routing_key = MessageHeader.generate_routing_key('Configuration', 'ConfigurationSetKeysRequest')
        header.set_routing_key(routing_key)
        super(ConfigurationSetKeysRequest, self).__init__(header, None)

    @classmethod
    def from_dict(cls, body_dict):
        """
        Create a new instance of :class:`ConfigurationSetKeysRequest` using a dictionary.

        :param body_dict: The body as a dictionary.
        :type body_dict: dict
        :return: A new instance of :class:`ConfigurationSetKeysRequest`.
        :rtype: ConfigurationSetKeysRequest
        """
        user_ = body_dict.get('user')
        section_ = body_dict.get('section')
        keys_ = body_dict.get('keys')
        return cls(
            user_=user_,
            section_=section_,
            keys_=keys_
        )

    @classmethod
    def from_json(cls, body_json):
        """
        Create a new instance of :class:`ConfigurationSetKeysRequest` using a JSON string.

        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`ConfigurationSetKeysRequest`.
        :rtype: ConfigurationSetKeysRequest
        """
        body_dict = json.loads(body_json)
        return cls.from_dict(body_dict)

    @classmethod
    def from_body_bytes(cls, body_bytes):
        """
        Create a new instance of :class:`ConfigurationSetKeysRequest` using a body
        of type :class:`bytes` or :class:`bytesarray`,

        :param body_bytes: The body to use.
        :type body_bytes: bytes or bytesarray
        :return: A new instance of :class:`ConfigurationSetKeysRequest`.
        :rtype: ConfigurationSetKeysRequest
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(body_json)

    @classmethod
    def from_message(cls, message):
        """
        Create a new instance of :class`ConfigurationSetKeysRequest` using a
        :class:`niskyline.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: niskyline.messagebus.message_base.MessageBase
        :return: A new instance of :class`ConfigurationSetKeysRequest`.
        :rtype: ConfigurationSetKeysRequest
        """
        instance = cls.from_body_bytes(message.get_body_bytes())
        instance.set_correlation_id(message.get_correlation_id())
        instance.set_reply_to(message.get_reply_to())
        return instance

    def to_dict(self):
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: dict
        """
        user_ = self.user
        section_ = self.section
        keys_ = self.keys
        return {
            'user': user_,
            'section': section_,
            'keys': keys_
        }

    def to_json(self):
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        body_json = self.to_json()
        return bytearray(body_json, 'utf-8')

    def to_message(self, request_message=None):
        """
        Returns a :class:`niskyline.messagebus.message_base.MessageBase`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :return: A :class:`niskyline.messagebus.message_base.MessageBase`
            object representing the data in this object.
        :rtype: niskyline.messagebus.message_base.MessageBase
        """
        header = self.get_header()
        if request_message:
            request_header = request_message.get_header()
            header.set_correlation_id(request_header.get_correlation_id())
        body_bytes = self.to_body_bytes()
        return MessageBase(header, body_bytes)

    def get_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body


class ConfigurationSetKeysResponse(ResponseMessage):
    """
    ConfigurationSetKeysResponse JSON response message.
    """
    def __init__(self,
                 request_message):
        """
        """
        header = MessageHeader()
        header.set_message_name('ConfigurationSetKeysResponse')
        header.set_content_type(JSON_MESSAGE_CONTENT_TYPE)
        # If request_message is None, routing key needs to be set outside this constructor.
        if request_message:
            header.set_correlation_id(request_message.get_correlation_id())
            routing_key = MessageHeader.generate_routing_key(request_message.get_reply_to(), 'ConfigurationSetKeysResponse')
            header.set_routing_key(routing_key)
        super(ConfigurationSetKeysResponse, self).__init__(header, None)

    @classmethod
    def from_dict(cls, request_message, body_dict):  # pylint: disable=unused-argument
        """
        Create a new instance of :class:`ConfigurationSetKeysResponse` using a dictionary.

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param body_dict: The body as a dictionary.
        :type body_dict: dict
        :return: A new instance of :class:`ConfigurationSetKeysResponse`.
        :rtype: ConfigurationSetKeysResponse
        """
        return cls(
            request_message
        )

    @classmethod
    def from_json(cls, request_message, body_json):
        """
        Create a new instance of :class:`ConfigurationSetKeysResponse` using a JSON string.

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`ConfigurationSetKeysResponse`.
        :rtype: ConfigurationSetKeysResponse
        """
        body_dict = json.loads(body_json)
        return cls.from_dict(request_message, body_dict)

    @classmethod
    def from_body_bytes(cls, request_message, body_bytes):
        """
        Create a new instance of :class:`ConfigurationSetKeysResponse` using a body
        of type :class:`bytes` or :class:`bytesarray`,

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param body_bytes: The body to use.
        :type body_bytes: bytes or bytesarray
        :return: A new instance of :class:`ConfigurationSetKeysResponse`.
        :rtype: ConfigurationSetKeysResponse
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(request_message, body_json)

    @classmethod
    def from_message(cls, message):
        """
        Create a new instance of :class`ConfigurationSetKeysResponse` using a
        :class:`niskyline.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: niskyline.messagebus.message_base.MessageBase
        :return: A new instance of :class`ConfigurationSetKeysResponse`.
        :rtype: ConfigurationSetKeysResponse
        """
        instance = cls.from_body_bytes(message, message.get_body_bytes())
        instance.set_correlation_id(message.get_correlation_id())
        instance.set_reply_to(message.get_reply_to())
        routing_key = MessageHeader.generate_routing_key(message.get_reply_to(), 'ConfigurationSetKeysResponse')
        instance.set_routing_key(routing_key)
        return instance

    def to_dict(self):  # pylint: disable=no-self-use
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: dict
        """
        return {
        }

    def to_json(self):
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        body_json = self.to_json()
        return bytearray(body_json, 'utf-8')

    def to_message(self, request_message=None):
        """
        Returns a :class:`niskyline.messagebus.message_base.MessageBase`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :return: A :class:`niskyline.messagebus.message_base.MessageBase`
            object representing the data in this object.
        :rtype: niskyline.messagebus.message_base.MessageBase
        """
        header = self.get_header()
        if request_message:
            request_header = request_message.get_header()
            header.set_correlation_id(request_header.get_correlation_id())
            routing_key = MessageHeader.generate_routing_key(request_header.get_reply_to(), 'ConfigurationSetKeysResponse')
            header.set_routing_key(routing_key)
        body_bytes = self.to_body_bytes()
        return MessageBase(header, body_bytes)

    def get_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body


class ConfigurationGetValueRequest(RequestMessage):
    """
    ConfigurationGetValueRequest JSON request message.
    """
    def __init__(self,
                 section_,
                 key_):
        """
        :param section_: section
        :type section_: str
        :param key_: key
        :type key_: str
        """
        self.section = section_
        self.key = key_
        header = MessageHeader()
        header.set_message_name('ConfigurationGetValueRequest')
        header.set_content_type(JSON_MESSAGE_CONTENT_TYPE)
        routing_key = MessageHeader.generate_routing_key('Configuration', 'ConfigurationGetValueRequest')
        header.set_routing_key(routing_key)
        super(ConfigurationGetValueRequest, self).__init__(header, None)

    @classmethod
    def from_dict(cls, body_dict):
        """
        Create a new instance of :class:`ConfigurationGetValueRequest` using a dictionary.

        :param body_dict: The body as a dictionary.
        :type body_dict: dict
        :return: A new instance of :class:`ConfigurationGetValueRequest`.
        :rtype: ConfigurationGetValueRequest
        """
        section_ = body_dict.get('section')
        key_ = body_dict.get('key')
        return cls(
            section_=section_,
            key_=key_
        )

    @classmethod
    def from_json(cls, body_json):
        """
        Create a new instance of :class:`ConfigurationGetValueRequest` using a JSON string.

        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`ConfigurationGetValueRequest`.
        :rtype: ConfigurationGetValueRequest
        """
        body_dict = json.loads(body_json)
        return cls.from_dict(body_dict)

    @classmethod
    def from_body_bytes(cls, body_bytes):
        """
        Create a new instance of :class:`ConfigurationGetValueRequest` using a body
        of type :class:`bytes` or :class:`bytesarray`,

        :param body_bytes: The body to use.
        :type body_bytes: bytes or bytesarray
        :return: A new instance of :class:`ConfigurationGetValueRequest`.
        :rtype: ConfigurationGetValueRequest
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(body_json)

    @classmethod
    def from_message(cls, message):
        """
        Create a new instance of :class`ConfigurationGetValueRequest` using a
        :class:`niskyline.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: niskyline.messagebus.message_base.MessageBase
        :return: A new instance of :class`ConfigurationGetValueRequest`.
        :rtype: ConfigurationGetValueRequest
        """
        instance = cls.from_body_bytes(message.get_body_bytes())
        instance.set_correlation_id(message.get_correlation_id())
        instance.set_reply_to(message.get_reply_to())
        return instance

    def to_dict(self):
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: dict
        """
        section_ = self.section
        key_ = self.key
        return {
            'section': section_,
            'key': key_
        }

    def to_json(self):
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        body_json = self.to_json()
        return bytearray(body_json, 'utf-8')

    def to_message(self, request_message=None):
        """
        Returns a :class:`niskyline.messagebus.message_base.MessageBase`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :return: A :class:`niskyline.messagebus.message_base.MessageBase`
            object representing the data in this object.
        :rtype: niskyline.messagebus.message_base.MessageBase
        """
        header = self.get_header()
        if request_message:
            request_header = request_message.get_header()
            header.set_correlation_id(request_header.get_correlation_id())
        body_bytes = self.to_body_bytes()
        return MessageBase(header, body_bytes)

    def get_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body


class ConfigurationGetValueResponse(ResponseMessage):
    """
    ConfigurationGetValueResponse JSON response message.
    """
    def __init__(self,
                 request_message,
                 value_):
        """
        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param value_: value
        :type value_: str
        """
        self.value = value_
        header = MessageHeader()
        header.set_message_name('ConfigurationGetValueResponse')
        header.set_content_type(JSON_MESSAGE_CONTENT_TYPE)
        # If request_message is None, routing key needs to be set outside this constructor.
        if request_message:
            header.set_correlation_id(request_message.get_correlation_id())
            routing_key = MessageHeader.generate_routing_key(request_message.get_reply_to(), 'ConfigurationGetValueResponse')
            header.set_routing_key(routing_key)
        super(ConfigurationGetValueResponse, self).__init__(header, None)

    @classmethod
    def from_dict(cls, request_message, body_dict):
        """
        Create a new instance of :class:`ConfigurationGetValueResponse` using a dictionary.

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param body_dict: The body as a dictionary.
        :type body_dict: dict
        :return: A new instance of :class:`ConfigurationGetValueResponse`.
        :rtype: ConfigurationGetValueResponse
        """
        value_ = body_dict.get('value')
        return cls(
            request_message,
            value_=value_
        )

    @classmethod
    def from_json(cls, request_message, body_json):
        """
        Create a new instance of :class:`ConfigurationGetValueResponse` using a JSON string.

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`ConfigurationGetValueResponse`.
        :rtype: ConfigurationGetValueResponse
        """
        body_dict = json.loads(body_json)
        return cls.from_dict(request_message, body_dict)

    @classmethod
    def from_body_bytes(cls, request_message, body_bytes):
        """
        Create a new instance of :class:`ConfigurationGetValueResponse` using a body
        of type :class:`bytes` or :class:`bytesarray`,

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param body_bytes: The body to use.
        :type body_bytes: bytes or bytesarray
        :return: A new instance of :class:`ConfigurationGetValueResponse`.
        :rtype: ConfigurationGetValueResponse
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(request_message, body_json)

    @classmethod
    def from_message(cls, message):
        """
        Create a new instance of :class`ConfigurationGetValueResponse` using a
        :class:`niskyline.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: niskyline.messagebus.message_base.MessageBase
        :return: A new instance of :class`ConfigurationGetValueResponse`.
        :rtype: ConfigurationGetValueResponse
        """
        instance = cls.from_body_bytes(message, message.get_body_bytes())
        instance.set_correlation_id(message.get_correlation_id())
        instance.set_reply_to(message.get_reply_to())
        routing_key = MessageHeader.generate_routing_key(message.get_reply_to(), 'ConfigurationGetValueResponse')
        instance.set_routing_key(routing_key)
        return instance

    def to_dict(self):
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: dict
        """
        value_ = self.value
        return {
            'value': value_
        }

    def to_json(self):
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        body_json = self.to_json()
        return bytearray(body_json, 'utf-8')

    def to_message(self, request_message=None):
        """
        Returns a :class:`niskyline.messagebus.message_base.MessageBase`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :return: A :class:`niskyline.messagebus.message_base.MessageBase`
            object representing the data in this object.
        :rtype: niskyline.messagebus.message_base.MessageBase
        """
        header = self.get_header()
        if request_message:
            request_header = request_message.get_header()
            header.set_correlation_id(request_header.get_correlation_id())
            routing_key = MessageHeader.generate_routing_key(request_header.get_reply_to(), 'ConfigurationGetValueResponse')
            header.set_routing_key(routing_key)
        body_bytes = self.to_body_bytes()
        return MessageBase(header, body_bytes)

    def get_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body


class ConfigurationSetValueRequest(RequestMessage):
    """
    ConfigurationSetValueRequest JSON request message.
    """
    def __init__(self,
                 user_,
                 section_,
                 key_,
                 value_):
        """
        :param user_: user
        :type user_: str
        :param section_: section
        :type section_: str
        :param key_: key
        :type key_: str
        :param value_: value
        :type value_: str
        """
        self.user = user_
        self.section = section_
        self.key = key_
        self.value = value_
        header = MessageHeader()
        header.set_message_name('ConfigurationSetValueRequest')
        header.set_content_type(JSON_MESSAGE_CONTENT_TYPE)
        routing_key = MessageHeader.generate_routing_key('Configuration', 'ConfigurationSetValueRequest')
        header.set_routing_key(routing_key)
        super(ConfigurationSetValueRequest, self).__init__(header, None)

    @classmethod
    def from_dict(cls, body_dict):
        """
        Create a new instance of :class:`ConfigurationSetValueRequest` using a dictionary.

        :param body_dict: The body as a dictionary.
        :type body_dict: dict
        :return: A new instance of :class:`ConfigurationSetValueRequest`.
        :rtype: ConfigurationSetValueRequest
        """
        user_ = body_dict.get('user')
        section_ = body_dict.get('section')
        key_ = body_dict.get('key')
        value_ = body_dict.get('value')
        return cls(
            user_=user_,
            section_=section_,
            key_=key_,
            value_=value_
        )

    @classmethod
    def from_json(cls, body_json):
        """
        Create a new instance of :class:`ConfigurationSetValueRequest` using a JSON string.

        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`ConfigurationSetValueRequest`.
        :rtype: ConfigurationSetValueRequest
        """
        body_dict = json.loads(body_json)
        return cls.from_dict(body_dict)

    @classmethod
    def from_body_bytes(cls, body_bytes):
        """
        Create a new instance of :class:`ConfigurationSetValueRequest` using a body
        of type :class:`bytes` or :class:`bytesarray`,

        :param body_bytes: The body to use.
        :type body_bytes: bytes or bytesarray
        :return: A new instance of :class:`ConfigurationSetValueRequest`.
        :rtype: ConfigurationSetValueRequest
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(body_json)

    @classmethod
    def from_message(cls, message):
        """
        Create a new instance of :class`ConfigurationSetValueRequest` using a
        :class:`niskyline.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: niskyline.messagebus.message_base.MessageBase
        :return: A new instance of :class`ConfigurationSetValueRequest`.
        :rtype: ConfigurationSetValueRequest
        """
        instance = cls.from_body_bytes(message.get_body_bytes())
        instance.set_correlation_id(message.get_correlation_id())
        instance.set_reply_to(message.get_reply_to())
        return instance

    def to_dict(self):
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: dict
        """
        user_ = self.user
        section_ = self.section
        key_ = self.key
        value_ = self.value
        return {
            'user': user_,
            'section': section_,
            'key': key_,
            'value': value_
        }

    def to_json(self):
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        body_json = self.to_json()
        return bytearray(body_json, 'utf-8')

    def to_message(self, request_message=None):
        """
        Returns a :class:`niskyline.messagebus.message_base.MessageBase`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :return: A :class:`niskyline.messagebus.message_base.MessageBase`
            object representing the data in this object.
        :rtype: niskyline.messagebus.message_base.MessageBase
        """
        header = self.get_header()
        if request_message:
            request_header = request_message.get_header()
            header.set_correlation_id(request_header.get_correlation_id())
        body_bytes = self.to_body_bytes()
        return MessageBase(header, body_bytes)

    def get_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body


class ConfigurationSetValueResponse(ResponseMessage):
    """
    ConfigurationSetValueResponse JSON response message.
    """
    def __init__(self,
                 request_message):
        """
        """
        header = MessageHeader()
        header.set_message_name('ConfigurationSetValueResponse')
        header.set_content_type(JSON_MESSAGE_CONTENT_TYPE)
        # If request_message is None, routing key needs to be set outside this constructor.
        if request_message:
            header.set_correlation_id(request_message.get_correlation_id())
            routing_key = MessageHeader.generate_routing_key(request_message.get_reply_to(), 'ConfigurationSetValueResponse')
            header.set_routing_key(routing_key)
        super(ConfigurationSetValueResponse, self).__init__(header, None)

    @classmethod
    def from_dict(cls, request_message, body_dict):  # pylint: disable=unused-argument
        """
        Create a new instance of :class:`ConfigurationSetValueResponse` using a dictionary.

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param body_dict: The body as a dictionary.
        :type body_dict: dict
        :return: A new instance of :class:`ConfigurationSetValueResponse`.
        :rtype: ConfigurationSetValueResponse
        """
        return cls(
            request_message
        )

    @classmethod
    def from_json(cls, request_message, body_json):
        """
        Create a new instance of :class:`ConfigurationSetValueResponse` using a JSON string.

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`ConfigurationSetValueResponse`.
        :rtype: ConfigurationSetValueResponse
        """
        body_dict = json.loads(body_json)
        return cls.from_dict(request_message, body_dict)

    @classmethod
    def from_body_bytes(cls, request_message, body_bytes):
        """
        Create a new instance of :class:`ConfigurationSetValueResponse` using a body
        of type :class:`bytes` or :class:`bytesarray`,

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param body_bytes: The body to use.
        :type body_bytes: bytes or bytesarray
        :return: A new instance of :class:`ConfigurationSetValueResponse`.
        :rtype: ConfigurationSetValueResponse
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(request_message, body_json)

    @classmethod
    def from_message(cls, message):
        """
        Create a new instance of :class`ConfigurationSetValueResponse` using a
        :class:`niskyline.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: niskyline.messagebus.message_base.MessageBase
        :return: A new instance of :class`ConfigurationSetValueResponse`.
        :rtype: ConfigurationSetValueResponse
        """
        instance = cls.from_body_bytes(message, message.get_body_bytes())
        instance.set_correlation_id(message.get_correlation_id())
        instance.set_reply_to(message.get_reply_to())
        routing_key = MessageHeader.generate_routing_key(message.get_reply_to(), 'ConfigurationSetValueResponse')
        instance.set_routing_key(routing_key)
        return instance

    def to_dict(self):  # pylint: disable=no-self-use
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: dict
        """
        return {
        }

    def to_json(self):
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        body_json = self.to_json()
        return bytearray(body_json, 'utf-8')

    def to_message(self, request_message=None):
        """
        Returns a :class:`niskyline.messagebus.message_base.MessageBase`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :return: A :class:`niskyline.messagebus.message_base.MessageBase`
            object representing the data in this object.
        :rtype: niskyline.messagebus.message_base.MessageBase
        """
        header = self.get_header()
        if request_message:
            request_header = request_message.get_header()
            header.set_correlation_id(request_header.get_correlation_id())
            routing_key = MessageHeader.generate_routing_key(request_header.get_reply_to(), 'ConfigurationSetValueResponse')
            header.set_routing_key(routing_key)
        body_bytes = self.to_body_bytes()
        return MessageBase(header, body_bytes)

    def get_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body


class ConfigurationGetSectionsRequest(RequestMessage):
    """
    ConfigurationGetSectionsRequest JSON request message.
    """
    def __init__(self):
        """
        """
        header = MessageHeader()
        header.set_message_name('ConfigurationGetSectionsRequest')
        header.set_content_type(JSON_MESSAGE_CONTENT_TYPE)
        routing_key = MessageHeader.generate_routing_key('Configuration', 'ConfigurationGetSectionsRequest')
        header.set_routing_key(routing_key)
        super(ConfigurationGetSectionsRequest, self).__init__(header, None)

    @classmethod
    def from_dict(cls, body_dict):  # pylint: disable=unused-argument
        """
        Create a new instance of :class:`ConfigurationGetSectionsRequest` using a dictionary.

        :param body_dict: The body as a dictionary.
        :type body_dict: dict
        :return: A new instance of :class:`ConfigurationGetSectionsRequest`.
        :rtype: ConfigurationGetSectionsRequest
        """
        return cls(
        )

    @classmethod
    def from_json(cls, body_json):
        """
        Create a new instance of :class:`ConfigurationGetSectionsRequest` using a JSON string.

        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`ConfigurationGetSectionsRequest`.
        :rtype: ConfigurationGetSectionsRequest
        """
        body_dict = json.loads(body_json)
        return cls.from_dict(body_dict)

    @classmethod
    def from_body_bytes(cls, body_bytes):
        """
        Create a new instance of :class:`ConfigurationGetSectionsRequest` using a body
        of type :class:`bytes` or :class:`bytesarray`,

        :param body_bytes: The body to use.
        :type body_bytes: bytes or bytesarray
        :return: A new instance of :class:`ConfigurationGetSectionsRequest`.
        :rtype: ConfigurationGetSectionsRequest
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(body_json)

    @classmethod
    def from_message(cls, message):
        """
        Create a new instance of :class`ConfigurationGetSectionsRequest` using a
        :class:`niskyline.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: niskyline.messagebus.message_base.MessageBase
        :return: A new instance of :class`ConfigurationGetSectionsRequest`.
        :rtype: ConfigurationGetSectionsRequest
        """
        instance = cls.from_body_bytes(message.get_body_bytes())
        instance.set_correlation_id(message.get_correlation_id())
        instance.set_reply_to(message.get_reply_to())
        return instance

    def to_dict(self):  # pylint: disable=no-self-use
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: dict
        """
        return {
        }

    def to_json(self):
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        body_json = self.to_json()
        return bytearray(body_json, 'utf-8')

    def to_message(self, request_message=None):
        """
        Returns a :class:`niskyline.messagebus.message_base.MessageBase`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :return: A :class:`niskyline.messagebus.message_base.MessageBase`
            object representing the data in this object.
        :rtype: niskyline.messagebus.message_base.MessageBase
        """
        header = self.get_header()
        if request_message:
            request_header = request_message.get_header()
            header.set_correlation_id(request_header.get_correlation_id())
        body_bytes = self.to_body_bytes()
        return MessageBase(header, body_bytes)

    def get_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body


class ConfigurationGetSectionsResponse(ResponseMessage):
    """
    ConfigurationGetSectionsResponse JSON response message.
    """
    def __init__(self,
                 request_message,
                 sections_):
        """
        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param sections_: sections
        :type sections_: list(str)
        """
        self.sections = sections_
        header = MessageHeader()
        header.set_message_name('ConfigurationGetSectionsResponse')
        header.set_content_type(JSON_MESSAGE_CONTENT_TYPE)
        # If request_message is None, routing key needs to be set outside this constructor.
        if request_message:
            header.set_correlation_id(request_message.get_correlation_id())
            routing_key = MessageHeader.generate_routing_key(request_message.get_reply_to(), 'ConfigurationGetSectionsResponse')
            header.set_routing_key(routing_key)
        super(ConfigurationGetSectionsResponse, self).__init__(header, None)

    @classmethod
    def from_dict(cls, request_message, body_dict):
        """
        Create a new instance of :class:`ConfigurationGetSectionsResponse` using a dictionary.

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param body_dict: The body as a dictionary.
        :type body_dict: dict
        :return: A new instance of :class:`ConfigurationGetSectionsResponse`.
        :rtype: ConfigurationGetSectionsResponse
        """
        sections_ = body_dict.get('sections')
        return cls(
            request_message,
            sections_=sections_
        )

    @classmethod
    def from_json(cls, request_message, body_json):
        """
        Create a new instance of :class:`ConfigurationGetSectionsResponse` using a JSON string.

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`ConfigurationGetSectionsResponse`.
        :rtype: ConfigurationGetSectionsResponse
        """
        body_dict = json.loads(body_json)
        return cls.from_dict(request_message, body_dict)

    @classmethod
    def from_body_bytes(cls, request_message, body_bytes):
        """
        Create a new instance of :class:`ConfigurationGetSectionsResponse` using a body
        of type :class:`bytes` or :class:`bytesarray`,

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param body_bytes: The body to use.
        :type body_bytes: bytes or bytesarray
        :return: A new instance of :class:`ConfigurationGetSectionsResponse`.
        :rtype: ConfigurationGetSectionsResponse
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(request_message, body_json)

    @classmethod
    def from_message(cls, message):
        """
        Create a new instance of :class`ConfigurationGetSectionsResponse` using a
        :class:`niskyline.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: niskyline.messagebus.message_base.MessageBase
        :return: A new instance of :class`ConfigurationGetSectionsResponse`.
        :rtype: ConfigurationGetSectionsResponse
        """
        instance = cls.from_body_bytes(message, message.get_body_bytes())
        instance.set_correlation_id(message.get_correlation_id())
        instance.set_reply_to(message.get_reply_to())
        routing_key = MessageHeader.generate_routing_key(message.get_reply_to(), 'ConfigurationGetSectionsResponse')
        instance.set_routing_key(routing_key)
        return instance

    def to_dict(self):
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: dict
        """
        sections_ = self.sections
        return {
            'sections': sections_
        }

    def to_json(self):
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        body_json = self.to_json()
        return bytearray(body_json, 'utf-8')

    def to_message(self, request_message=None):
        """
        Returns a :class:`niskyline.messagebus.message_base.MessageBase`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :return: A :class:`niskyline.messagebus.message_base.MessageBase`
            object representing the data in this object.
        :rtype: niskyline.messagebus.message_base.MessageBase
        """
        header = self.get_header()
        if request_message:
            request_header = request_message.get_header()
            header.set_correlation_id(request_header.get_correlation_id())
            routing_key = MessageHeader.generate_routing_key(request_header.get_reply_to(), 'ConfigurationGetSectionsResponse')
            header.set_routing_key(routing_key)
        body_bytes = self.to_body_bytes()
        return MessageBase(header, body_bytes)

    def get_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body


class ConfigurationGetSectionKeyValuesRequest(RequestMessage):
    """
    ConfigurationGetSectionKeyValuesRequest JSON request message.
    """
    def __init__(self):
        """
        """
        header = MessageHeader()
        header.set_message_name('ConfigurationGetSectionKeyValuesRequest')
        header.set_content_type(JSON_MESSAGE_CONTENT_TYPE)
        routing_key = MessageHeader.generate_routing_key('Configuration', 'ConfigurationGetSectionKeyValuesRequest')
        header.set_routing_key(routing_key)
        super(ConfigurationGetSectionKeyValuesRequest, self).__init__(header, None)

    @classmethod
    def from_dict(cls, body_dict):  # pylint: disable=unused-argument
        """
        Create a new instance of :class:`ConfigurationGetSectionKeyValuesRequest` using a dictionary.

        :param body_dict: The body as a dictionary.
        :type body_dict: dict
        :return: A new instance of :class:`ConfigurationGetSectionKeyValuesRequest`.
        :rtype: ConfigurationGetSectionKeyValuesRequest
        """
        return cls(
        )

    @classmethod
    def from_json(cls, body_json):
        """
        Create a new instance of :class:`ConfigurationGetSectionKeyValuesRequest` using a JSON string.

        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`ConfigurationGetSectionKeyValuesRequest`.
        :rtype: ConfigurationGetSectionKeyValuesRequest
        """
        body_dict = json.loads(body_json)
        return cls.from_dict(body_dict)

    @classmethod
    def from_body_bytes(cls, body_bytes):
        """
        Create a new instance of :class:`ConfigurationGetSectionKeyValuesRequest` using a body
        of type :class:`bytes` or :class:`bytesarray`,

        :param body_bytes: The body to use.
        :type body_bytes: bytes or bytesarray
        :return: A new instance of :class:`ConfigurationGetSectionKeyValuesRequest`.
        :rtype: ConfigurationGetSectionKeyValuesRequest
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(body_json)

    @classmethod
    def from_message(cls, message):
        """
        Create a new instance of :class`ConfigurationGetSectionKeyValuesRequest` using a
        :class:`niskyline.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: niskyline.messagebus.message_base.MessageBase
        :return: A new instance of :class`ConfigurationGetSectionKeyValuesRequest`.
        :rtype: ConfigurationGetSectionKeyValuesRequest
        """
        instance = cls.from_body_bytes(message.get_body_bytes())
        instance.set_correlation_id(message.get_correlation_id())
        instance.set_reply_to(message.get_reply_to())
        return instance

    def to_dict(self):  # pylint: disable=no-self-use
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: dict
        """
        return {
        }

    def to_json(self):
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        body_json = self.to_json()
        return bytearray(body_json, 'utf-8')

    def to_message(self, request_message=None):
        """
        Returns a :class:`niskyline.messagebus.message_base.MessageBase`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :return: A :class:`niskyline.messagebus.message_base.MessageBase`
            object representing the data in this object.
        :rtype: niskyline.messagebus.message_base.MessageBase
        """
        header = self.get_header()
        if request_message:
            request_header = request_message.get_header()
            header.set_correlation_id(request_header.get_correlation_id())
        body_bytes = self.to_body_bytes()
        return MessageBase(header, body_bytes)

    def get_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body


class ConfigurationGetSectionKeyValuesResponse(ResponseMessage):
    """
    ConfigurationGetSectionKeyValuesResponse JSON response message.
    """
    def __init__(self,
                 request_message,
                 key_values_):
        """
        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param key_values_: key_values
        :type key_values_: list(SectionKeyValues)
        """
        self.key_values = key_values_
        header = MessageHeader()
        header.set_message_name('ConfigurationGetSectionKeyValuesResponse')
        header.set_content_type(JSON_MESSAGE_CONTENT_TYPE)
        # If request_message is None, routing key needs to be set outside this constructor.
        if request_message:
            header.set_correlation_id(request_message.get_correlation_id())
            routing_key = MessageHeader.generate_routing_key(request_message.get_reply_to(), 'ConfigurationGetSectionKeyValuesResponse')
            header.set_routing_key(routing_key)
        super(ConfigurationGetSectionKeyValuesResponse, self).__init__(header, None)

    @classmethod
    def from_dict(cls, request_message, body_dict):
        """
        Create a new instance of :class:`ConfigurationGetSectionKeyValuesResponse` using a dictionary.

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param body_dict: The body as a dictionary.
        :type body_dict: dict
        :return: A new instance of :class:`ConfigurationGetSectionKeyValuesResponse`.
        :rtype: ConfigurationGetSectionKeyValuesResponse
        """
        key_values_ = body_dict.get('keyValues')
        if key_values_ is not None:
            new_list = []
            for item in key_values_:
                item = SectionKeyValues.from_dict(item)
                new_list.append(item)
            key_values_ = new_list
        return cls(
            request_message,
            key_values_=key_values_
        )

    @classmethod
    def from_json(cls, request_message, body_json):
        """
        Create a new instance of :class:`ConfigurationGetSectionKeyValuesResponse` using a JSON string.

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`ConfigurationGetSectionKeyValuesResponse`.
        :rtype: ConfigurationGetSectionKeyValuesResponse
        """
        body_dict = json.loads(body_json)
        return cls.from_dict(request_message, body_dict)

    @classmethod
    def from_body_bytes(cls, request_message, body_bytes):
        """
        Create a new instance of :class:`ConfigurationGetSectionKeyValuesResponse` using a body
        of type :class:`bytes` or :class:`bytesarray`,

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param body_bytes: The body to use.
        :type body_bytes: bytes or bytesarray
        :return: A new instance of :class:`ConfigurationGetSectionKeyValuesResponse`.
        :rtype: ConfigurationGetSectionKeyValuesResponse
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(request_message, body_json)

    @classmethod
    def from_message(cls, message):
        """
        Create a new instance of :class`ConfigurationGetSectionKeyValuesResponse` using a
        :class:`niskyline.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: niskyline.messagebus.message_base.MessageBase
        :return: A new instance of :class`ConfigurationGetSectionKeyValuesResponse`.
        :rtype: ConfigurationGetSectionKeyValuesResponse
        """
        instance = cls.from_body_bytes(message, message.get_body_bytes())
        instance.set_correlation_id(message.get_correlation_id())
        instance.set_reply_to(message.get_reply_to())
        routing_key = MessageHeader.generate_routing_key(message.get_reply_to(), 'ConfigurationGetSectionKeyValuesResponse')
        instance.set_routing_key(routing_key)
        return instance

    def to_dict(self):
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: dict
        """
        key_values_ = self.key_values
        if key_values_ is not None:
            new_list = []
            for item in key_values_:
                new_list.append(item.to_dict())
            key_values_ = new_list
        return {
            'keyValues': key_values_
        }

    def to_json(self):
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        body_json = self.to_json()
        return bytearray(body_json, 'utf-8')

    def to_message(self, request_message=None):
        """
        Returns a :class:`niskyline.messagebus.message_base.MessageBase`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :return: A :class:`niskyline.messagebus.message_base.MessageBase`
            object representing the data in this object.
        :rtype: niskyline.messagebus.message_base.MessageBase
        """
        header = self.get_header()
        if request_message:
            request_header = request_message.get_header()
            header.set_correlation_id(request_header.get_correlation_id())
            routing_key = MessageHeader.generate_routing_key(request_header.get_reply_to(), 'ConfigurationGetSectionKeyValuesResponse')
            header.set_routing_key(routing_key)
        body_bytes = self.to_body_bytes()
        return MessageBase(header, body_bytes)

    def get_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body
