# -*- coding: utf-8 -*-
"""
Implementation of 'ErrorCode' class
"""
from __future__ import absolute_import


class ErrorCode(object):  # pylint: disable=too-many-public-methods
    """
    Skyline Error Code information.

    For use with the :class:`niskyline.messagebus.error.Error` class.
    """
    def __init__(self, category, name, message=None):
        """
        :param category: The category of the error.
        :type category: str
        :param name: The name of the error.
        :type name: str
        :param message: The error message or ``None`` if there is no error
            message.
        :type message: str or None
        """
        self._category = category
        self._name = name
        self._message = message

    def get_category(self):
        """
        Get the category of the error.

        :return: The category of the error.
        :rtype: str
        """
        return self._category

    def set_category(self, category):
        """
        Set the category of the error.

        :param category: The category of the error.
        :type category: str
        """
        self._category = category

    def get_name(self):
        """
        Get the name of the error.

        :return: The name of the error.
        :rtype: str
        """
        return self._name

    def set_name(self, name):
        """
        Set the name of the error.

        :param name: The name of the error.
        :type name: str
        """
        self._name = name

    def get_message(self):
        """
        Get the error message.

        :return: The error message or ``None`` if there is no error
            message.
        :rtype: str or None
        """
        return self._message

    def set_message(self, message):
        """
        Set the error message.

        :param message: The error message or ``None`` if there is no error
            message.
        :type message: str or None
        """
        self._message = message

    def to_string(self):
        """
        Return a string representation of the error code.

        :return: A string representation of the error code.
        :rtype: str
        """
        if not self._category:
            return self._name
        return self._category + '.' + self._name
