# -*- coding: utf-8 -*-
"""
Implementation of 'SkylineException' and related classes
"""
from __future__ import absolute_import

# Skyline error codes
SUCCESS = 0
ERROR_INTERNAL_SKYLINE_SERVICE_ERROR = -251000
ERROR_REQUEST_TIMED_OUT = -251001
ERROR_IO_ERROR = -251002
ERROR_OUT_OF_MEMORY = -251003
ERROR_GENERIC_ERROR = -251004  # Try to avoid using this generic error code
ERROR_FAILED_TO_PARSE = -251005
ERROR_INVALID_SEMAPHORE_INITIALIZATION = -251006
ERROR_INSUFFICIENT_RESOURCES = -251007
ERROR_NOT_SUPPORTED = -251008
ERROR_INSUFFICIENT_PRIVILEGES = -251009
ERROR_ATTEMPT_TO_REINITIALIZE_WITH_MULTIPLE_CONFIGURATIONS = -251010
ERROR_NO_SKYLINE_CONFIGURATIONS_AVAILABLE = -251011
ERROR_SKYLINE_CONFIGURATIONS_DIRECTORY_NOT_FOUND = -251012
ERROR_DUPLICATE_CONFIGURATION_ID = -251013
ERROR_END_OF_STREAM = -251014
ERROR_QUEUE_EMPTY = -251015
ERROR_FAILED_TO_INITIALIZE_NISSL = -251016
AMQP_ERROR_OPENING_TCP_CONNECTION = -251017
AMQP_ERROR_CLOSING_TCP_CONNECTION = -251018
AMQP_ERROR_ENDING_TCP_CONNECTION = -251019
AMQP_ERROR_CREATING_TCP_SOCKET = -251020
AMQP_ERROR_CREATING_SSL_SOCKET = -251021
AMQP_ERROR_OPENING_SOCKET = -251022
AMQP_ERROR_SETTING_CA_CERTIFICATE = -251023
AMQP_ERROR_FAILED_TO_LOG_IN = -251024
AMQP_ERROR_OPENING_CHANNEL = -251025
AMQP_ERROR_DECLARING_QUEUE = -251026
AMQP_ERROR_OBTAINING_QUEUE_NAME = -251027
AMQP_ERROR_BINDING_QUEUE = -251028
AMQP_ERROR_UNBINDING_QUEUE = -251029
AMQP_ERROR_DECLARING_EXCHANGE = -251030
AMQP_ERROR_PERFORMING_BASIC_CONSUME = -251031
AMQP_ERROR_PUBLISHING_MESSAGE = -251032
AMQP_ERROR_DEQUEUEING_MESSAGE = -251033
AMQP_ERROR_CERT_EXPIRED = -251034
AMQP_ERROR_PEER_VERIFY_FAILED = -251035
ERROR_FAILED_TO_LOAD_CERT = -251036
ERROR_UNEXPECTED_EXCEPTION = -251037
ERROR_NOT_FOUND = -251038
ERROR_UNABLE_TO_LOAD_CLIENT_LIBRARY = -251039
AMQP_ERROR_SETTING_QOS = -251040
ERROR_ONE_OR_MORE_ERRORS_OCCURRED = -251041


class SkylineException(Exception):
    """
    Base exception class: all Skyline-specific exceptions should subclass this
    """
    def __init__(self, message, error_code=ERROR_GENERIC_ERROR):
        """
        :param message: The error message.
        :type message: str
        :param error_code: The Skyline error code.
        :type error_code: int
        """
        super(SkylineException, self).__init__(message)
        self.message = message
        self.error_code = error_code

    def __repr__(self):
        ret = '[Error Code {0}] {1}'.format(self.error_code, self.message)
        return ret.strip()

    __str__ = __repr__


class AmqpException(SkylineException):
    """
    Used when an AMQP related error occurs
    """
