# -*- coding: utf-8 -*-
"""
DO NOT EDIT! This file is auto-generated

Classes for Skyline Message Bus usage.
"""
from __future__ import absolute_import

# Import python libs
import json
import sys
from datetime import datetime  # pylint: disable=unused-import

# Import local libs
# pylint: disable=import-error
from niskyline.messagebus.broadcast_message import BroadcastMessage  # pylint: disable=unused-import
from niskyline.messagebus.datetime import from_datetime, to_datetime  # pylint: disable=unused-import
from niskyline.messagebus.message_header import (  # pylint: disable=unused-import
    MessageHeader, JSON_MESSAGE_CONTENT_TYPE, BINARY_MESSAGE_CONTENT_TYPE)
from niskyline.messagebus.message_base import MessageBase
from niskyline.messagebus.request_message import RequestMessage  # pylint: disable=unused-import
from niskyline.messagebus.response_message import ResponseMessage  # pylint: disable=unused-import
from niskyline.messagebus.routed_message import RoutedMessage  # pylint: disable=unused-import
# pylint: enable=import-error

if sys.version_info[0] >= 3:
    long = int  # pylint: disable=redefined-builtin,invalid-name


# pylint: disable=line-too-long,too-many-lines,too-many-instance-attributes


#
# TraceLogger service
#


class LogType(object):  # pylint: disable=too-few-public-methods
    """
    LogType normal enum.
    """
    LOG = 0
    ERROR = 1
    INFO = 2
    _INT_TO_STRING = {
        0: 'LOG',
        1: 'ERROR',
        2: 'INFO'
    }
    _STRING_TO_INT = {
        'LOG': 0,
        'ERROR': 1,
        'INFO': 2
    }

    def __init__(self, value):
        """
        :param value: The integer value of the enum.
        :type value: int
        """
        self._value = value

    def get_value(self):
        """
        Get integer value of the enum.

        :return: The integer value of the enum.
        :rtype: int
        """
        return self._value

    def set_value(self, value):
        """
        Set integer value of the enum.

        :param value: The integer value of the enum.
        :type value: int
        """
        self._value = value

    @classmethod
    def from_string(cls, value_string):
        """
        Create a new instance of :class:`LogType` using a string.

        :param value_string: The string value of the enum.
        :type value_string: str
        :return: A new instance of :class:`LogType`.
        :rtype: LogType
        """
        value = cls._STRING_TO_INT[value_string]
        return cls(value)

    def to_string(self):
        """
        Returns a string representing the enum.

        :return: A string representing the enum.
        :rtype: str
        """
        return self._INT_TO_STRING[self._value]


class LogEntry(object):
    """
    LogEntry custom data type.
    """
    def __init__(self,
                 module_name_,
                 timestamp_,
                 trace_point_name_,
                 text_,
                 type_):
        """
        :param module_name_: module_name
        :type module_name_: str
        :param timestamp_: timestamp
        :type timestamp_: datetime
        :param trace_point_name_: trace_point_name
        :type trace_point_name_: str
        :param text_: text
        :type text_: str
        :param type_: type
        :type type_: LogType
        """
        self.module_name = module_name_
        self.timestamp = timestamp_
        self.trace_point_name = trace_point_name_
        self.text = text_
        self.type = type_

    @classmethod
    def from_dict(cls, body_dict):
        """
        Create a new instance of :class:`LogEntry` using a dictionary.

        :param body_dict: A dictionary representing the body.
        :type body_dict: dict
        :return: A new instance of :class:`LogEntry`.
        :rtype: LogEntry
        """
        module_name_ = body_dict.get('moduleName')
        timestamp_ = body_dict.get('timestamp')
        if timestamp_ is not None and not isinstance(timestamp_, datetime):
            timestamp_ = to_datetime(timestamp_)
        trace_point_name_ = body_dict.get('tracePointName')
        text_ = body_dict.get('text')
        type_ = body_dict.get('type')
        if type_ is not None:
            if isinstance(type_, str):
                type_ = LogType.from_string(type_)
            elif isinstance(type_, int):
                type_ = LogType(type_)
        return cls(
            module_name_=module_name_,
            timestamp_=timestamp_,
            trace_point_name_=trace_point_name_,
            text_=text_,
            type_=type_
        )

    @classmethod
    def from_json(cls, body_json):
        """
        Create a new instance of :class:`LogEntry` using a JSON string.

        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`LogEntry`.
        :rtype: LogEntry
        """
        body_dict = json.loads(body_json)
        return cls.from_dict(body_dict)

    @classmethod
    def from_body_bytes(cls, body_bytes):
        """
        Create a new instance of :class:`LogEntry` using a body
        of type :class:`bytes` or :class:`bytesarray`.

        :param body_bytes: The body to use.
        :type body_bytes: bytes or bytesarray
        :return: A new instance of :class:`LogEntry`.
        :rtype: LogEntry
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(body_json)

    def to_dict(self):
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: dict
        """
        module_name_ = self.module_name
        timestamp_ = self.timestamp
        if timestamp_ is not None and isinstance(timestamp_, datetime):
            timestamp_ = from_datetime(timestamp_)
        trace_point_name_ = self.trace_point_name
        text_ = self.text
        type_ = self.type
        if type_ is not None:
            type_ = type_.to_string()
        return {
            'moduleName': module_name_,
            'timestamp': timestamp_,
            'tracePointName': trace_point_name_,
            'text': text_,
            'type': type_
        }

    def to_json(self):
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        body_json = self.to_json()
        return bytearray(body_json, 'utf-8')


class TracePointSetting(object):
    """
    TracePointSetting custom data type.
    """
    def __init__(self,
                 name_,
                 enabled_,
                 exceptions_,
                 times_):
        """
        :param name_: name
        :type name_: str
        :param enabled_: enabled
        :type enabled_: bool
        :param exceptions_: exceptions
        :type exceptions_: list(str)
        :param times_: times
        :type times_: str
        """
        self.name = name_
        self.enabled = enabled_
        self.exceptions = exceptions_
        self.times = times_

    @classmethod
    def from_dict(cls, body_dict):
        """
        Create a new instance of :class:`TracePointSetting` using a dictionary.

        :param body_dict: A dictionary representing the body.
        :type body_dict: dict
        :return: A new instance of :class:`TracePointSetting`.
        :rtype: TracePointSetting
        """
        name_ = body_dict.get('name')
        enabled_ = body_dict.get('enabled')
        exceptions_ = body_dict.get('exceptions')
        times_ = body_dict.get('times')
        return cls(
            name_=name_,
            enabled_=enabled_,
            exceptions_=exceptions_,
            times_=times_
        )

    @classmethod
    def from_json(cls, body_json):
        """
        Create a new instance of :class:`TracePointSetting` using a JSON string.

        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`TracePointSetting`.
        :rtype: TracePointSetting
        """
        body_dict = json.loads(body_json)
        return cls.from_dict(body_dict)

    @classmethod
    def from_body_bytes(cls, body_bytes):
        """
        Create a new instance of :class:`TracePointSetting` using a body
        of type :class:`bytes` or :class:`bytesarray`.

        :param body_bytes: The body to use.
        :type body_bytes: bytes or bytesarray
        :return: A new instance of :class:`TracePointSetting`.
        :rtype: TracePointSetting
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(body_json)

    def to_dict(self):
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: dict
        """
        name_ = self.name
        enabled_ = self.enabled
        exceptions_ = self.exceptions
        times_ = self.times
        return {
            'name': name_,
            'enabled': enabled_,
            'exceptions': exceptions_,
            'times': times_
        }

    def to_json(self):
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        body_json = self.to_json()
        return bytearray(body_json, 'utf-8')


class TraceLoggerStoreEntriesRoutedMessage(RoutedMessage):
    """
    TraceLoggerStoreEntriesRoutedMessage JSON routed message.
    """
    def __init__(self,
                 entries_):
        """
        :param entries_: entries
        :type entries_: list(LogEntry)
        """
        self.entries = entries_
        header = MessageHeader()
        header.set_message_name('TraceLoggerStoreEntriesRoutedMessage')
        header.set_content_type(JSON_MESSAGE_CONTENT_TYPE)
        routing_key = MessageHeader.generate_routing_key('TraceLogger', 'TraceLoggerStoreEntriesRoutedMessage')
        header.set_routing_key(routing_key)
        super(TraceLoggerStoreEntriesRoutedMessage, self).__init__(header, None)

    @classmethod
    def from_dict(cls, body_dict):
        """
        Create a new instance of :class:`TraceLoggerStoreEntriesRoutedMessage` using a dictionary.

        :param body_dict: The body as a dictionary.
        :type body_dict: dict
        :return: A new instance of :class:`TraceLoggerStoreEntriesRoutedMessage`.
        :rtype: TraceLoggerStoreEntriesRoutedMessage
        """
        entries_ = body_dict.get('entries')
        if entries_ is not None:
            new_list = []
            for item in entries_:
                item = LogEntry.from_dict(item)
                new_list.append(item)
            entries_ = new_list
        return cls(
            entries_=entries_
        )

    @classmethod
    def from_json(cls, body_json):
        """
        Create a new instance of :class:`TraceLoggerStoreEntriesRoutedMessage` using a JSON string.

        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`TraceLoggerStoreEntriesRoutedMessage`.
        :rtype: TraceLoggerStoreEntriesRoutedMessage
        """
        body_dict = json.loads(body_json)
        return cls.from_dict(body_dict)

    @classmethod
    def from_body_bytes(cls, body_bytes):
        """
        Create a new instance of :class:`TraceLoggerStoreEntriesRoutedMessage` using a body
        of type :class:`bytes` or :class:`bytesarray`,

        :param body_bytes: The body to use.
        :type body_bytes: bytes or bytesarray
        :return: A new instance of :class:`TraceLoggerStoreEntriesRoutedMessage`.
        :rtype: TraceLoggerStoreEntriesRoutedMessage
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(body_json)

    @classmethod
    def from_message(cls, message):
        """
        Create a new instance of :class`TraceLoggerStoreEntriesRoutedMessage` using a
        :class:`niskyline.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: niskyline.messagebus.message_base.MessageBase
        :return: A new instance of :class`TraceLoggerStoreEntriesRoutedMessage`.
        :rtype: TraceLoggerStoreEntriesRoutedMessage
        """
        instance = cls.from_body_bytes(message.get_body_bytes())
        instance.set_correlation_id(message.get_correlation_id())
        instance.set_reply_to(message.get_reply_to())
        return instance

    def to_dict(self):
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: dict
        """
        entries_ = self.entries
        if entries_ is not None:
            new_list = []
            for item in entries_:
                new_list.append(item.to_dict())
            entries_ = new_list
        return {
            'entries': entries_
        }

    def to_json(self):
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        body_json = self.to_json()
        return bytearray(body_json, 'utf-8')

    def to_message(self, request_message=None):
        """
        Returns a :class:`niskyline.messagebus.message_base.MessageBase`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :return: A :class:`niskyline.messagebus.message_base.MessageBase`
            object representing the data in this object.
        :rtype: niskyline.messagebus.message_base.MessageBase
        """
        header = self.get_header()
        if request_message:
            request_header = request_message.get_header()
            header.set_correlation_id(request_header.get_correlation_id())
        body_bytes = self.to_body_bytes()
        return MessageBase(header, body_bytes)

    def get_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body


class TraceLoggerRegisterTracePointRoutedMessage(RoutedMessage):
    """
    TraceLoggerRegisterTracePointRoutedMessage JSON routed message.
    """
    def __init__(self,
                 trace_point_name_):
        """
        :param trace_point_name_: trace_point_name
        :type trace_point_name_: str
        """
        self.trace_point_name = trace_point_name_
        header = MessageHeader()
        header.set_message_name('TraceLoggerRegisterTracePointRoutedMessage')
        header.set_content_type(JSON_MESSAGE_CONTENT_TYPE)
        routing_key = MessageHeader.generate_routing_key('TraceLogger', 'TraceLoggerRegisterTracePointRoutedMessage')
        header.set_routing_key(routing_key)
        super(TraceLoggerRegisterTracePointRoutedMessage, self).__init__(header, None)

    @classmethod
    def from_dict(cls, body_dict):
        """
        Create a new instance of :class:`TraceLoggerRegisterTracePointRoutedMessage` using a dictionary.

        :param body_dict: The body as a dictionary.
        :type body_dict: dict
        :return: A new instance of :class:`TraceLoggerRegisterTracePointRoutedMessage`.
        :rtype: TraceLoggerRegisterTracePointRoutedMessage
        """
        trace_point_name_ = body_dict.get('tracePointName')
        return cls(
            trace_point_name_=trace_point_name_
        )

    @classmethod
    def from_json(cls, body_json):
        """
        Create a new instance of :class:`TraceLoggerRegisterTracePointRoutedMessage` using a JSON string.

        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`TraceLoggerRegisterTracePointRoutedMessage`.
        :rtype: TraceLoggerRegisterTracePointRoutedMessage
        """
        body_dict = json.loads(body_json)
        return cls.from_dict(body_dict)

    @classmethod
    def from_body_bytes(cls, body_bytes):
        """
        Create a new instance of :class:`TraceLoggerRegisterTracePointRoutedMessage` using a body
        of type :class:`bytes` or :class:`bytesarray`,

        :param body_bytes: The body to use.
        :type body_bytes: bytes or bytesarray
        :return: A new instance of :class:`TraceLoggerRegisterTracePointRoutedMessage`.
        :rtype: TraceLoggerRegisterTracePointRoutedMessage
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(body_json)

    @classmethod
    def from_message(cls, message):
        """
        Create a new instance of :class`TraceLoggerRegisterTracePointRoutedMessage` using a
        :class:`niskyline.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: niskyline.messagebus.message_base.MessageBase
        :return: A new instance of :class`TraceLoggerRegisterTracePointRoutedMessage`.
        :rtype: TraceLoggerRegisterTracePointRoutedMessage
        """
        instance = cls.from_body_bytes(message.get_body_bytes())
        instance.set_correlation_id(message.get_correlation_id())
        instance.set_reply_to(message.get_reply_to())
        return instance

    def to_dict(self):
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: dict
        """
        trace_point_name_ = self.trace_point_name
        return {
            'tracePointName': trace_point_name_
        }

    def to_json(self):
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        body_json = self.to_json()
        return bytearray(body_json, 'utf-8')

    def to_message(self, request_message=None):
        """
        Returns a :class:`niskyline.messagebus.message_base.MessageBase`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :return: A :class:`niskyline.messagebus.message_base.MessageBase`
            object representing the data in this object.
        :rtype: niskyline.messagebus.message_base.MessageBase
        """
        header = self.get_header()
        if request_message:
            request_header = request_message.get_header()
            header.set_correlation_id(request_header.get_correlation_id())
        body_bytes = self.to_body_bytes()
        return MessageBase(header, body_bytes)

    def get_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body


class TraceLoggerBroadcastTracePointsRoutedMessage(RoutedMessage):
    """
    TraceLoggerBroadcastTracePointsRoutedMessage JSON routed message.
    """
    def __init__(self):
        """
        """
        header = MessageHeader()
        header.set_message_name('TraceLoggerBroadcastTracePointsRoutedMessage')
        header.set_content_type(JSON_MESSAGE_CONTENT_TYPE)
        routing_key = MessageHeader.generate_routing_key('TraceLogger', 'TraceLoggerBroadcastTracePointsRoutedMessage')
        header.set_routing_key(routing_key)
        super(TraceLoggerBroadcastTracePointsRoutedMessage, self).__init__(header, None)

    @classmethod
    def from_dict(cls, body_dict):  # pylint: disable=unused-argument
        """
        Create a new instance of :class:`TraceLoggerBroadcastTracePointsRoutedMessage` using a dictionary.

        :param body_dict: The body as a dictionary.
        :type body_dict: dict
        :return: A new instance of :class:`TraceLoggerBroadcastTracePointsRoutedMessage`.
        :rtype: TraceLoggerBroadcastTracePointsRoutedMessage
        """
        return cls(
        )

    @classmethod
    def from_json(cls, body_json):
        """
        Create a new instance of :class:`TraceLoggerBroadcastTracePointsRoutedMessage` using a JSON string.

        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`TraceLoggerBroadcastTracePointsRoutedMessage`.
        :rtype: TraceLoggerBroadcastTracePointsRoutedMessage
        """
        body_dict = json.loads(body_json)
        return cls.from_dict(body_dict)

    @classmethod
    def from_body_bytes(cls, body_bytes):
        """
        Create a new instance of :class:`TraceLoggerBroadcastTracePointsRoutedMessage` using a body
        of type :class:`bytes` or :class:`bytesarray`,

        :param body_bytes: The body to use.
        :type body_bytes: bytes or bytesarray
        :return: A new instance of :class:`TraceLoggerBroadcastTracePointsRoutedMessage`.
        :rtype: TraceLoggerBroadcastTracePointsRoutedMessage
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(body_json)

    @classmethod
    def from_message(cls, message):
        """
        Create a new instance of :class`TraceLoggerBroadcastTracePointsRoutedMessage` using a
        :class:`niskyline.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: niskyline.messagebus.message_base.MessageBase
        :return: A new instance of :class`TraceLoggerBroadcastTracePointsRoutedMessage`.
        :rtype: TraceLoggerBroadcastTracePointsRoutedMessage
        """
        instance = cls.from_body_bytes(message.get_body_bytes())
        instance.set_correlation_id(message.get_correlation_id())
        instance.set_reply_to(message.get_reply_to())
        return instance

    def to_dict(self):  # pylint: disable=no-self-use
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: dict
        """
        return {
        }

    def to_json(self):
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        body_json = self.to_json()
        return bytearray(body_json, 'utf-8')

    def to_message(self, request_message=None):
        """
        Returns a :class:`niskyline.messagebus.message_base.MessageBase`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :return: A :class:`niskyline.messagebus.message_base.MessageBase`
            object representing the data in this object.
        :rtype: niskyline.messagebus.message_base.MessageBase
        """
        header = self.get_header()
        if request_message:
            request_header = request_message.get_header()
            header.set_correlation_id(request_header.get_correlation_id())
        body_bytes = self.to_body_bytes()
        return MessageBase(header, body_bytes)

    def get_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body


class TraceLoggerSnapshotBroadcast(BroadcastMessage):
    """
    TraceLoggerSnapshotBroadcast JSON broadcast message.
    """
    def __init__(self,
                 settings_):
        """
        :param settings_: settings
        :type settings_: list(TracePointSetting)
        """
        self.settings = settings_
        header = MessageHeader()
        header.set_message_name('TraceLoggerSnapshotBroadcast')
        header.set_content_type(JSON_MESSAGE_CONTENT_TYPE)
        routing_key = MessageHeader.generate_routing_key(None, 'TraceLoggerSnapshotBroadcast')
        header.set_routing_key(routing_key)
        super(TraceLoggerSnapshotBroadcast, self).__init__(header, None)

    @classmethod
    def from_dict(cls, body_dict):
        """
        Create a new instance of :class:`TraceLoggerSnapshotBroadcast` using a dictionary.

        :param body_dict: The body as a dictionary.
        :type body_dict: dict
        :return: A new instance of :class:`TraceLoggerSnapshotBroadcast`.
        :rtype: TraceLoggerSnapshotBroadcast
        """
        settings_ = body_dict.get('settings')
        if settings_ is not None:
            new_list = []
            for item in settings_:
                item = TracePointSetting.from_dict(item)
                new_list.append(item)
            settings_ = new_list
        return cls(
            settings_=settings_
        )

    @classmethod
    def from_json(cls, body_json):
        """
        Create a new instance of :class:`TraceLoggerSnapshotBroadcast` using a JSON string.

        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`TraceLoggerSnapshotBroadcast`.
        :rtype: TraceLoggerSnapshotBroadcast
        """
        body_dict = json.loads(body_json)
        return cls.from_dict(body_dict)

    @classmethod
    def from_body_bytes(cls, body_bytes):
        """
        Create a new instance of :class:`TraceLoggerSnapshotBroadcast` using a body
        of type :class:`bytes` or :class:`bytesarray`,

        :param body_bytes: The body to use.
        :type body_bytes: bytes or bytesarray
        :return: A new instance of :class:`TraceLoggerSnapshotBroadcast`.
        :rtype: TraceLoggerSnapshotBroadcast
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(body_json)

    @classmethod
    def from_message(cls, message):
        """
        Create a new instance of :class`TraceLoggerSnapshotBroadcast` using a
        :class:`niskyline.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: niskyline.messagebus.message_base.MessageBase
        :return: A new instance of :class`TraceLoggerSnapshotBroadcast`.
        :rtype: TraceLoggerSnapshotBroadcast
        """
        instance = cls.from_body_bytes(message.get_body_bytes())
        instance.set_correlation_id(message.get_correlation_id())
        instance.set_reply_to(message.get_reply_to())
        return instance

    def to_dict(self):
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: dict
        """
        settings_ = self.settings
        if settings_ is not None:
            new_list = []
            for item in settings_:
                new_list.append(item.to_dict())
            settings_ = new_list
        return {
            'settings': settings_
        }

    def to_json(self):
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        body_json = self.to_json()
        return bytearray(body_json, 'utf-8')

    def to_message(self, request_message=None):
        """
        Returns a :class:`niskyline.messagebus.message_base.MessageBase`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :return: A :class:`niskyline.messagebus.message_base.MessageBase`
            object representing the data in this object.
        :rtype: niskyline.messagebus.message_base.MessageBase
        """
        header = self.get_header()
        if request_message:
            request_header = request_message.get_header()
            header.set_correlation_id(request_header.get_correlation_id())
        body_bytes = self.to_body_bytes()
        return MessageBase(header, body_bytes)

    def get_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body


class TraceLoggerTracePointListRequest(RequestMessage):
    """
    TraceLoggerTracePointListRequest JSON request message.
    """
    def __init__(self):
        """
        """
        header = MessageHeader()
        header.set_message_name('TraceLoggerTracePointListRequest')
        header.set_content_type(JSON_MESSAGE_CONTENT_TYPE)
        routing_key = MessageHeader.generate_routing_key('TraceLogger', 'TraceLoggerTracePointListRequest')
        header.set_routing_key(routing_key)
        super(TraceLoggerTracePointListRequest, self).__init__(header, None)

    @classmethod
    def from_dict(cls, body_dict):  # pylint: disable=unused-argument
        """
        Create a new instance of :class:`TraceLoggerTracePointListRequest` using a dictionary.

        :param body_dict: The body as a dictionary.
        :type body_dict: dict
        :return: A new instance of :class:`TraceLoggerTracePointListRequest`.
        :rtype: TraceLoggerTracePointListRequest
        """
        return cls(
        )

    @classmethod
    def from_json(cls, body_json):
        """
        Create a new instance of :class:`TraceLoggerTracePointListRequest` using a JSON string.

        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`TraceLoggerTracePointListRequest`.
        :rtype: TraceLoggerTracePointListRequest
        """
        body_dict = json.loads(body_json)
        return cls.from_dict(body_dict)

    @classmethod
    def from_body_bytes(cls, body_bytes):
        """
        Create a new instance of :class:`TraceLoggerTracePointListRequest` using a body
        of type :class:`bytes` or :class:`bytesarray`,

        :param body_bytes: The body to use.
        :type body_bytes: bytes or bytesarray
        :return: A new instance of :class:`TraceLoggerTracePointListRequest`.
        :rtype: TraceLoggerTracePointListRequest
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(body_json)

    @classmethod
    def from_message(cls, message):
        """
        Create a new instance of :class`TraceLoggerTracePointListRequest` using a
        :class:`niskyline.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: niskyline.messagebus.message_base.MessageBase
        :return: A new instance of :class`TraceLoggerTracePointListRequest`.
        :rtype: TraceLoggerTracePointListRequest
        """
        instance = cls.from_body_bytes(message.get_body_bytes())
        instance.set_correlation_id(message.get_correlation_id())
        instance.set_reply_to(message.get_reply_to())
        return instance

    def to_dict(self):  # pylint: disable=no-self-use
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: dict
        """
        return {
        }

    def to_json(self):
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        body_json = self.to_json()
        return bytearray(body_json, 'utf-8')

    def to_message(self, request_message=None):
        """
        Returns a :class:`niskyline.messagebus.message_base.MessageBase`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :return: A :class:`niskyline.messagebus.message_base.MessageBase`
            object representing the data in this object.
        :rtype: niskyline.messagebus.message_base.MessageBase
        """
        header = self.get_header()
        if request_message:
            request_header = request_message.get_header()
            header.set_correlation_id(request_header.get_correlation_id())
        body_bytes = self.to_body_bytes()
        return MessageBase(header, body_bytes)

    def get_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body


class TraceLoggerTracePointListResponse(ResponseMessage):
    """
    TraceLoggerTracePointListResponse JSON response message.
    """
    def __init__(self,
                 request_message,
                 settings_):
        """
        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param settings_: settings
        :type settings_: list(TracePointSetting)
        """
        self.settings = settings_
        header = MessageHeader()
        header.set_message_name('TraceLoggerTracePointListResponse')
        header.set_content_type(JSON_MESSAGE_CONTENT_TYPE)
        # If request_message is None, routing key needs to be set outside this constructor.
        if request_message:
            header.set_correlation_id(request_message.get_correlation_id())
            routing_key = MessageHeader.generate_routing_key(request_message.get_reply_to(), 'TraceLoggerTracePointListResponse')
            header.set_routing_key(routing_key)
        super(TraceLoggerTracePointListResponse, self).__init__(header, None)

    @classmethod
    def from_dict(cls, request_message, body_dict):
        """
        Create a new instance of :class:`TraceLoggerTracePointListResponse` using a dictionary.

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param body_dict: The body as a dictionary.
        :type body_dict: dict
        :return: A new instance of :class:`TraceLoggerTracePointListResponse`.
        :rtype: TraceLoggerTracePointListResponse
        """
        settings_ = body_dict.get('settings')
        if settings_ is not None:
            new_list = []
            for item in settings_:
                item = TracePointSetting.from_dict(item)
                new_list.append(item)
            settings_ = new_list
        return cls(
            request_message,
            settings_=settings_
        )

    @classmethod
    def from_json(cls, request_message, body_json):
        """
        Create a new instance of :class:`TraceLoggerTracePointListResponse` using a JSON string.

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`TraceLoggerTracePointListResponse`.
        :rtype: TraceLoggerTracePointListResponse
        """
        body_dict = json.loads(body_json)
        return cls.from_dict(request_message, body_dict)

    @classmethod
    def from_body_bytes(cls, request_message, body_bytes):
        """
        Create a new instance of :class:`TraceLoggerTracePointListResponse` using a body
        of type :class:`bytes` or :class:`bytesarray`,

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param body_bytes: The body to use.
        :type body_bytes: bytes or bytesarray
        :return: A new instance of :class:`TraceLoggerTracePointListResponse`.
        :rtype: TraceLoggerTracePointListResponse
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(request_message, body_json)

    @classmethod
    def from_message(cls, message):
        """
        Create a new instance of :class`TraceLoggerTracePointListResponse` using a
        :class:`niskyline.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: niskyline.messagebus.message_base.MessageBase
        :return: A new instance of :class`TraceLoggerTracePointListResponse`.
        :rtype: TraceLoggerTracePointListResponse
        """
        instance = cls.from_body_bytes(message, message.get_body_bytes())
        instance.set_correlation_id(message.get_correlation_id())
        instance.set_reply_to(message.get_reply_to())
        routing_key = MessageHeader.generate_routing_key(message.get_reply_to(), 'TraceLoggerTracePointListResponse')
        instance.set_routing_key(routing_key)
        return instance

    def to_dict(self):
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: dict
        """
        settings_ = self.settings
        if settings_ is not None:
            new_list = []
            for item in settings_:
                new_list.append(item.to_dict())
            settings_ = new_list
        return {
            'settings': settings_
        }

    def to_json(self):
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        body_json = self.to_json()
        return bytearray(body_json, 'utf-8')

    def to_message(self, request_message=None):
        """
        Returns a :class:`niskyline.messagebus.message_base.MessageBase`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :return: A :class:`niskyline.messagebus.message_base.MessageBase`
            object representing the data in this object.
        :rtype: niskyline.messagebus.message_base.MessageBase
        """
        header = self.get_header()
        if request_message:
            request_header = request_message.get_header()
            header.set_correlation_id(request_header.get_correlation_id())
            routing_key = MessageHeader.generate_routing_key(request_header.get_reply_to(), 'TraceLoggerTracePointListResponse')
            header.set_routing_key(routing_key)
        body_bytes = self.to_body_bytes()
        return MessageBase(header, body_bytes)

    def get_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body


class TraceLoggerCommandRequest(RequestMessage):
    """
    TraceLoggerCommandRequest JSON request message.
    """
    def __init__(self,
                 arguments_):
        """
        :param arguments_: arguments
        :type arguments_: list(str)
        """
        self.arguments = arguments_
        header = MessageHeader()
        header.set_message_name('TraceLoggerCommandRequest')
        header.set_content_type(JSON_MESSAGE_CONTENT_TYPE)
        routing_key = MessageHeader.generate_routing_key('TraceLogger', 'TraceLoggerCommandRequest')
        header.set_routing_key(routing_key)
        super(TraceLoggerCommandRequest, self).__init__(header, None)

    @classmethod
    def from_dict(cls, body_dict):
        """
        Create a new instance of :class:`TraceLoggerCommandRequest` using a dictionary.

        :param body_dict: The body as a dictionary.
        :type body_dict: dict
        :return: A new instance of :class:`TraceLoggerCommandRequest`.
        :rtype: TraceLoggerCommandRequest
        """
        arguments_ = body_dict.get('arguments')
        return cls(
            arguments_=arguments_
        )

    @classmethod
    def from_json(cls, body_json):
        """
        Create a new instance of :class:`TraceLoggerCommandRequest` using a JSON string.

        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`TraceLoggerCommandRequest`.
        :rtype: TraceLoggerCommandRequest
        """
        body_dict = json.loads(body_json)
        return cls.from_dict(body_dict)

    @classmethod
    def from_body_bytes(cls, body_bytes):
        """
        Create a new instance of :class:`TraceLoggerCommandRequest` using a body
        of type :class:`bytes` or :class:`bytesarray`,

        :param body_bytes: The body to use.
        :type body_bytes: bytes or bytesarray
        :return: A new instance of :class:`TraceLoggerCommandRequest`.
        :rtype: TraceLoggerCommandRequest
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(body_json)

    @classmethod
    def from_message(cls, message):
        """
        Create a new instance of :class`TraceLoggerCommandRequest` using a
        :class:`niskyline.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: niskyline.messagebus.message_base.MessageBase
        :return: A new instance of :class`TraceLoggerCommandRequest`.
        :rtype: TraceLoggerCommandRequest
        """
        instance = cls.from_body_bytes(message.get_body_bytes())
        instance.set_correlation_id(message.get_correlation_id())
        instance.set_reply_to(message.get_reply_to())
        return instance

    def to_dict(self):
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: dict
        """
        arguments_ = self.arguments
        return {
            'arguments': arguments_
        }

    def to_json(self):
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        body_json = self.to_json()
        return bytearray(body_json, 'utf-8')

    def to_message(self, request_message=None):
        """
        Returns a :class:`niskyline.messagebus.message_base.MessageBase`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :return: A :class:`niskyline.messagebus.message_base.MessageBase`
            object representing the data in this object.
        :rtype: niskyline.messagebus.message_base.MessageBase
        """
        header = self.get_header()
        if request_message:
            request_header = request_message.get_header()
            header.set_correlation_id(request_header.get_correlation_id())
        body_bytes = self.to_body_bytes()
        return MessageBase(header, body_bytes)

    def get_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body


class TraceLoggerCommandResponse(ResponseMessage):
    """
    TraceLoggerCommandResponse JSON response message.
    """
    def __init__(self,
                 request_message,
                 response_text_):
        """
        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param response_text_: response_text
        :type response_text_: list(str)
        """
        self.response_text = response_text_
        header = MessageHeader()
        header.set_message_name('TraceLoggerCommandResponse')
        header.set_content_type(JSON_MESSAGE_CONTENT_TYPE)
        # If request_message is None, routing key needs to be set outside this constructor.
        if request_message:
            header.set_correlation_id(request_message.get_correlation_id())
            routing_key = MessageHeader.generate_routing_key(request_message.get_reply_to(), 'TraceLoggerCommandResponse')
            header.set_routing_key(routing_key)
        super(TraceLoggerCommandResponse, self).__init__(header, None)

    @classmethod
    def from_dict(cls, request_message, body_dict):
        """
        Create a new instance of :class:`TraceLoggerCommandResponse` using a dictionary.

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param body_dict: The body as a dictionary.
        :type body_dict: dict
        :return: A new instance of :class:`TraceLoggerCommandResponse`.
        :rtype: TraceLoggerCommandResponse
        """
        response_text_ = body_dict.get('responseText')
        return cls(
            request_message,
            response_text_=response_text_
        )

    @classmethod
    def from_json(cls, request_message, body_json):
        """
        Create a new instance of :class:`TraceLoggerCommandResponse` using a JSON string.

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`TraceLoggerCommandResponse`.
        :rtype: TraceLoggerCommandResponse
        """
        body_dict = json.loads(body_json)
        return cls.from_dict(request_message, body_dict)

    @classmethod
    def from_body_bytes(cls, request_message, body_bytes):
        """
        Create a new instance of :class:`TraceLoggerCommandResponse` using a body
        of type :class:`bytes` or :class:`bytesarray`,

        :param request_message: The request_message to use for reply information. May be None.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :param body_bytes: The body to use.
        :type body_bytes: bytes or bytesarray
        :return: A new instance of :class:`TraceLoggerCommandResponse`.
        :rtype: TraceLoggerCommandResponse
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(request_message, body_json)

    @classmethod
    def from_message(cls, message):
        """
        Create a new instance of :class`TraceLoggerCommandResponse` using a
        :class:`niskyline.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: niskyline.messagebus.message_base.MessageBase
        :return: A new instance of :class`TraceLoggerCommandResponse`.
        :rtype: TraceLoggerCommandResponse
        """
        instance = cls.from_body_bytes(message, message.get_body_bytes())
        instance.set_correlation_id(message.get_correlation_id())
        instance.set_reply_to(message.get_reply_to())
        routing_key = MessageHeader.generate_routing_key(message.get_reply_to(), 'TraceLoggerCommandResponse')
        instance.set_routing_key(routing_key)
        return instance

    def to_dict(self):
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: dict
        """
        response_text_ = self.response_text
        return {
            'responseText': response_text_
        }

    def to_json(self):
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        body_json = self.to_json()
        return bytearray(body_json, 'utf-8')

    def to_message(self, request_message=None):
        """
        Returns a :class:`niskyline.messagebus.message_base.MessageBase`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :return: A :class:`niskyline.messagebus.message_base.MessageBase`
            object representing the data in this object.
        :rtype: niskyline.messagebus.message_base.MessageBase
        """
        header = self.get_header()
        if request_message:
            request_header = request_message.get_header()
            header.set_correlation_id(request_header.get_correlation_id())
            routing_key = MessageHeader.generate_routing_key(request_header.get_reply_to(), 'TraceLoggerCommandResponse')
            header.set_routing_key(routing_key)
        body_bytes = self.to_body_bytes()
        return MessageBase(header, body_bytes)

    def get_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body
